function [x, Flag] = P1_UpAIDS(BS, R, S, Win);
%%%%% Obtain Upper stage AIDS estimate

TW = BS(:,1); TLP=BS(:,2); TPI=BS(:,3);TLXP = BS(:,4);
Region = BS(:,5:8); Season = BS(:,9:11); Winter=BS(:,11);

% Generate the LnP regressors
tmp = zeros(96,8);
tmp(:) = TLP;                   % prices of eight segments
TLPM = repmat(tmp, 8, 1);

% DataMatrix has 10 columns: const, eight segment prices, TLXP, 
DataMatrix = zeros(768,10);
DataMatrix = [ones(768,1), TLPM, TLXP];

% Define constraints: Add-Up, Homogeneity, Symmetry
[Aeq, beq] = P2_UpDummyCon(R,S,Win);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Define the constraint matrix, w/ region or season dummies 
%Estimate the parameters subject to the constraints
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
options = optimset('LargeScale','Off');
if R==1 & S==0 & Win==0                 %Using regional dummies alone
    x_0 = zeros(104,1);                  
    C = zeros(768,104);
    for i = 1: 8;
        C(1+(i-1)*96:i*96,1+(i-1)*10:i*10) = DataMatrix(1+(i-1)*96:i*96 ,:);
        C(1+(i-1)*96:i*96,81+(i-1)*3:80+i*3) = Region(1+(i-1)*96:i*96,2:4);
    end;
    [x, resnorm, residual, Flag] = lsqlin(C, TW, [],[],Aeq, beq,[],[],x_0,options);
elseif R==1 & S==0 & Win==1             %Using regional & Winter dummies
    x_0 = zeros(112,1);   
    C = zeros(768,112);
    for i = 1: 8;
        C(1+(i-1)*96:i*96,1+(i-1)*10:i*10) = DataMatrix(1+(i-1)*96:i*96 ,:);
        C(1+(i-1)*96:i*96,81+(i-1)*3:80+i*3) = Region(1+(i-1)*96:i*96,2:4);
        C(1+(i-1)*96:i*96,104+i) = Winter(1+(i-1)*96:i*96);
    end;
    [x, resnorm, residual, Flag] = lsqlin(C, TW, [],[],Aeq, beq,[],[],x_0,options);
elseif R==1 & S==1 & Win==0             %Using regional & seasonal dummies
    x_0 = zeros(120,1);   
    C = zeros(768,120);
    for i = 1: 8;
        C(1+(i-1)*96:i*96,1+(i-1)*10:i*10) = DataMatrix(1+(i-1)*96:i*96 ,:);
        C(1+(i-1)*96:i*96,81+(i-1)*3:80+i*3) = Region(1+(i-1)*96:i*96,2:4);
        C(1+(i-1)*96:i*96,105+(i-1)*2:104+i*2) = Season(1+(i-1)*96:i*96,2:3);
    end;
    [x, resnorm, residual, Flag] = lsqlin(C, TW, [],[],Aeq, beq,[],[],x_0,options);
elseif R==0 & S==0 & Win==0                 %No dummies
    x_0 = zeros(80,1);                  
    C = zeros(768,80);
    for i = 1: 8;
        C(1+(i-1)*96:i*96,1+(i-1)*10:i*10) = DataMatrix(1+(i-1)*96:i*96 ,:);
    end;
    [x, resnorm, residual, Flag] = lsqlin(C, TW, [],[],Aeq, beq,[],[],x_0,options);
end;

