function [SW,SLP,SPI,SLXP] = P7_LowInitial(BS,R,S,Win)
% Obtain Lower stage starting point for Counter-factual
% BS is the bootstrap sample 
% R,S,Win are dummies: R=1 if using regional dummies, S=1 if using seasonal
% dummies, Win=1 if using winter dummies
% SW, SLP, SPI, SLXP are the average revenue share, log of product price,
%   price index, and quinolone expenditure observed in the sample

if R==1 & S==0 & Win==0
    SW=zeros(28,1); SLP=zeros(28,1); SPI=zeros(4,1); SLXP=zeros(4,1);
    for i=1:7
        tmp = BS((i-1)*96+1:i*96,:);
        tw = tmp(:,1);tp=tmp(:,2);tpi=tmp(:,3);txp=tmp(:,4);
        for k=1:4
            SW((k-1)*7+i)=mean(tw(tmp(:,k+4)==1));
            SLP((k-1)*7+i) =mean(tp(tmp(:,k+4)==1));
            SPI(k)=mean(tpi(tmp(:,k+4)==1));
            SLXP(k)=mean(txp(tmp(:,k+4)==1));
        end;
    end;
elseif R==1 & S==0 & Win==1
    SW=zeros(56,1); SLP=zeros(56,1); SPI=zeros(8,1); SLXP=zeros(8,1);
    for i=1:7
        tmp = BS((i-1)*96+1:i*96,:);
        tw = tmp(:,1);tp=tmp(:,2);tpi=tmp(:,3);txp=tmp(:,4);
        for k=1:4
            SW((k-1)*7+i)=mean(tw(tmp(:,k+4)==1 & tmp(:,11)==0));
            SLP((k-1)*7+i) =mean(tp(tmp(:,k+4)==1 & tmp(:,11)==0));
            SPI(k)=mean(tpi(tmp(:,k+4)==1 & tmp(:,11)==0));
            SLXP(k)=mean(txp(tmp(:,k+4)==1 & tmp(:,11)==0));

            SW((k+3)*7+i)=mean(tw(tmp(:,k+4)==1 & tmp(:,11)==1));
            SLP((k+3)*7+i) =mean(tp(tmp(:,k+4)==1 & tmp(:,11)==1));
            SPI(k+4)=mean(tpi(tmp(:,k+4)==1 & tmp(:,11)==1));
            SLXP(k+4)=mean(txp(tmp(:,k+4)==1 & tmp(:,11)==1));
        end;
    end;
elseif R==0 & S==0 & Win==0
    SW=zeros(7,1); SLP=zeros(7,1); 
    for i=1:7
        tmp = BS((i-1)*96+1:i*96,:);
        SW(i)=mean(tmp(:,1));
        SLP(i)=mean(tmp(:,2));
    end;
    SPI=mean(BS(1:96,3));
    SLXP=mean(BS(1:96,4));
end;

